@@ -8,7 +8,7 @@
  */
 
 /*
-Copyright 2009, 2010, 2011, 2012 Free Software Foundation, Inc.
+Copyright 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
 Contributed by the AriC and Caramel projects, INRIA.
 
 This file is part of the GNU MPFR Library.
@@ -58,32 +58,32 @@ int main (int argc, char **argv)
 
   mpfr_inits2 (prec, LIST, (mpfr_ptr) 0);
 
-  if (mpfr_set_str (x, argv[2], 0, GMP_RNDN))
+  if (mpfr_set_str (x, argv[2], 0, MPFR_RNDN))
     {
       fprintf (stderr, "rndo-add: bad x value\n");
       exit (1);
     }
   mpfr_printf ("x = %.*Rb\n", pprec, x);
 
-  if (mpfr_set_str (y, argv[3], 0, GMP_RNDN))
+  if (mpfr_set_str (y, argv[3], 0, MPFR_RNDN))
     {
       fprintf (stderr, "rndo-add: bad y value\n");
       exit (1);
     }
   mpfr_printf ("y = %.*Rb\n", pprec, y);
 
-  mpfr_add (d, x, y, GMP_RNDD);
+  mpfr_add (d, x, y, MPFR_RNDD);
   mpfr_printf ("d = %.*Rb\n", pprec, d);
 
-  mpfr_add (u, x, y, GMP_RNDU);
+  mpfr_add (u, x, y, MPFR_RNDU);
   mpfr_printf ("u = %.*Rb\n", pprec, u);
 
-  mpfr_add (e, d, u, GMP_RNDN);
-  mpfr_div_2ui (e, e, 1, GMP_RNDN);
+  mpfr_add (e, d, u, MPFR_RNDN);
+  mpfr_div_2ui (e, e, 1, MPFR_RNDN);
   mpfr_printf ("e = %.*Rb\n", pprec, e);
 
-  mpfr_sub (z, u, e, GMP_RNDN);
-  mpfr_add (z, z, d, GMP_RNDN);
+  mpfr_sub (z, u, e, MPFR_RNDN);
+  mpfr_add (z, z, d, MPFR_RNDN);
   mpfr_printf ("z = %.*Rb\n", pprec, z);
 
   mpfr_clears (LIST, (mpfr_ptr) 0);
