@@ -1,24 +1,24 @@
 /* Test file for mpfr_min & mpfr_max.
 
-Copyright 2004, 2006, 2007, 2008 Free Software Foundation, Inc.
-Contributed by the Arenaire and Cacao projects, INRIA.
+Copyright 2004, 2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013 Free Software Foundation, Inc.
+Contributed by the AriC and Caramel projects, INRIA.
 
-This file is part of the MPFR Library.
+This file is part of the GNU MPFR Library.
 
-The MPFR Library is free software; you can redistribute it and/or modify
+The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
-the Free Software Foundation; either version 2.1 of the License, or (at your
+the Free Software Foundation; either version 3 of the License, or (at your
 option) any later version.
 
-The MPFR Library is distributed in the hope that it will be useful, but
+The GNU MPFR Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the MPFR Library; see the file COPYING.LIB.  If not, write to
-the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
-MA 02110-1301, USA. */
+along with the GNU MPFR Library; see the file COPYING.LESSER.  If not, see
+http://www.gnu.org/licenses/ or write to the Free Software Foundation, Inc.,
+51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA. */
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -39,13 +39,13 @@ main (void)
   /* case x=NaN && y=NAN */
   mpfr_set_nan (x);
   mpfr_set_nan (y);
-  mpfr_min (z, x, y, GMP_RNDN);
+  mpfr_min (z, x, y, MPFR_RNDN);
   if (!mpfr_nan_p (z))
     {
       printf ("Error in mpfr_min (NaN, NaN)\n");
       exit (1);
     }
-  mpfr_max (z, x, y, GMP_RNDN);
+  mpfr_max (z, x, y, MPFR_RNDN);
   if (!mpfr_nan_p (z))
     {
       printf ("Error in mpfr_max (NaN, NaN)\n");
@@ -53,56 +53,56 @@ main (void)
     }
   /* case x=NaN */
   mpfr_set_nan (x);
-  mpfr_set_ui (y, 0, GMP_RNDN);
-  mpfr_min (z, x, y, GMP_RNDN);
+  mpfr_set_ui (y, 0, MPFR_RNDN);
+  mpfr_min (z, x, y, MPFR_RNDN);
   if (mpfr_cmp_ui (z, 0))
     {
       printf ("Error in mpfr_min (NaN, 0)\n");
       exit (1);
     }
-  mpfr_min (z, y, x, GMP_RNDN);
+  mpfr_min (z, y, x, MPFR_RNDN);
   if (mpfr_cmp_ui (z, 0))
     {
       printf ("Error in mpfr_min (0, NaN)\n");
       exit (1);
     }
-  mpfr_max (z, x, y, GMP_RNDN);
+  mpfr_max (z, x, y, MPFR_RNDN);
   if (mpfr_cmp_ui (z, 0))
     {
       printf ("Error in mpfr_max (NaN, 0)\n");
       exit (1);
     }
-  mpfr_max (z, y, x, GMP_RNDN);
+  mpfr_max (z, y, x, MPFR_RNDN);
   if (mpfr_cmp_ui (z, 0))
     {
       printf ("Error in mpfr_max (0, NaN)\n");
       exit (1);
     }
   /* Case x=0+ and x=0- */
-  mpfr_set_ui (x, 0, GMP_RNDN);
-  mpfr_set_ui (y, 0, GMP_RNDN); MPFR_SET_NEG(y);
-  mpfr_max (z, x, y, GMP_RNDN);
+  mpfr_set_ui (x, 0, MPFR_RNDN);
+  mpfr_set_ui (y, 0, MPFR_RNDN); MPFR_SET_NEG(y);
+  mpfr_max (z, x, y, MPFR_RNDN);
   if (!MPFR_IS_ZERO(z) || MPFR_IS_NEG(z))
     {
       printf ("Error in mpfr_max (0+, 0-)\n");
       exit (1);
     }
-  mpfr_min (z, x, y, GMP_RNDN);
+  mpfr_min (z, x, y, MPFR_RNDN);
   if (!MPFR_IS_ZERO(z) || MPFR_IS_POS(z))
     {
       printf ("Error in mpfr_min (0+, 0-)\n");
       exit (1);
     }
   /* Case x=0- and y=0+ */
-  mpfr_set_ui (x, 0, GMP_RNDN); MPFR_SET_NEG(x);
-  mpfr_set_ui (y, 0, GMP_RNDN);
-  mpfr_max (z, x, y, GMP_RNDN);
+  mpfr_set_ui (x, 0, MPFR_RNDN); MPFR_SET_NEG(x);
+  mpfr_set_ui (y, 0, MPFR_RNDN);
+  mpfr_max (z, x, y, MPFR_RNDN);
   if (!MPFR_IS_ZERO(z) || MPFR_IS_NEG(z))
     {
       printf ("Error in mpfr_max (0+, 0-)\n");
       exit (1);
     }
-  mpfr_min (z, x, y, GMP_RNDN);
+  mpfr_min (z, x, y, MPFR_RNDN);
   if (!MPFR_IS_ZERO(z) || MPFR_IS_POS(z))
     {
       printf ("Error in mpfr_min (0+, 0-)\n");
@@ -111,14 +111,14 @@ main (void)
 
   /* case x=+Inf */
   mpfr_set_inf (x, 1);
-  mpfr_set_si (y, -12, GMP_RNDN);
-  mpfr_min (z, x, y, GMP_RNDN);
+  mpfr_set_si (y, -12, MPFR_RNDN);
+  mpfr_min (z, x, y, MPFR_RNDN);
   if ( mpfr_cmp_si (z, -12) )
     {
       printf ("Error in mpfr_min (+Inf, -12)\n");
       exit (1);
     }
-  mpfr_max (z, x, y, GMP_RNDN);
+  mpfr_max (z, x, y, MPFR_RNDN);
   if ( !MPFR_IS_INF(z) || MPFR_IS_NEG(z) )
     {
       printf ("Error in mpfr_max (+Inf, 12)\n");
@@ -126,14 +126,14 @@ main (void)
     }
   /* case x=-Inf */
   mpfr_set_inf (x, -1);
-  mpfr_set_ui (y, 12, GMP_RNDN);
-  mpfr_max (z, x, y, GMP_RNDN);
+  mpfr_set_ui (y, 12, MPFR_RNDN);
+  mpfr_max (z, x, y, MPFR_RNDN);
   if ( mpfr_cmp_ui (z, 12) )
     {
       printf ("Error in mpfr_max (-Inf, 12)\n");
       exit (1);
     }
-  mpfr_min (z, x, y, GMP_RNDN);
+  mpfr_min (z, x, y, MPFR_RNDN);
   if ( !MPFR_IS_INF(z) || MPFR_IS_POS(z) )
     {
       printf ("Error in mpfr_min (-Inf, 12)\n");
@@ -141,21 +141,21 @@ main (void)
     }
 
   /* case x=17 and y=42 */
-  mpfr_set_ui (x, 17, GMP_RNDN);
-  mpfr_set_ui (y, 42, GMP_RNDN);
-  mpfr_max (z, x, y, GMP_RNDN);
+  mpfr_set_ui (x, 17, MPFR_RNDN);
+  mpfr_set_ui (y, 42, MPFR_RNDN);
+  mpfr_max (z, x, y, MPFR_RNDN);
   if ( mpfr_cmp_ui (z, 42) )
     {
       printf ("Error in mpfr_max (17, 42)\n");
       exit (1);
     }
-  mpfr_max (z, y, x, GMP_RNDN);
+  mpfr_max (z, y, x, MPFR_RNDN);
   if ( mpfr_cmp_ui (z, 42) )
     {
       printf ("Error in mpfr_max (42, 17)\n");
       exit (1);
     }
-  mpfr_min (z, y, x, GMP_RNDN);
+  mpfr_min (z, y, x, MPFR_RNDN);
   if ( mpfr_cmp_ui (z, 17) )
     {
       printf ("Error in mpfr_min (42, 17)\n");
